/*
   File: empty.h
   classifies the hyper_rules into predicates, non predicates and
   rules starting with a semi terminal.
  
   CVS ID: "$Id: empty.h,v 1.3 2004/12/26 00:48:45 marcs Exp $"
*/
#ifndef IncEmpty
#define IncEmpty

void do_empty_classification ();

#endif /* IncEmpty */
